package X6FRs_4.IMuAHx_6.Mqv2r_3;

import android.app.Notification;
import android.app.PendingIntent;
import android.content.Context;
import android.graphics.Bitmap;
import android.os.Build;
import android.os.Bundle;
import android.widget.RemoteViews;
import java.util.ArrayList;
/* compiled from: NotificationCompat.java */
/* loaded from: classes.dex */
public class IFxWkV_5 {

    /* compiled from: NotificationCompat.java */
    /* loaded from: classes.dex */
    public static class KQgRr5e_0 {
        public final int KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public PendingIntent f418KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public final Bundle f419KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public CharSequence f420KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public boolean f421KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public final Xgtqvk_8[] f422KQgRr5e_0;
        public int QxJ9d_1;

        /* renamed from: QxJ9d_1  reason: collision with other field name */
        public boolean f423QxJ9d_1;

        /* renamed from: QxJ9d_1  reason: collision with other field name */
        public final Xgtqvk_8[] f424QxJ9d_1;

        public int KQgRr5e_0() {
            return this.QxJ9d_1;
        }

        /* renamed from: QxJ9d_1  reason: collision with other method in class */
        public Xgtqvk_8[] m304QxJ9d_1() {
            return this.f422KQgRr5e_0;
        }

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public CharSequence m300KQgRr5e_0() {
            return this.f420KQgRr5e_0;
        }

        public int QxJ9d_1() {
            return this.KQgRr5e_0;
        }

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public PendingIntent m298KQgRr5e_0() {
            return this.f418KQgRr5e_0;
        }

        /* renamed from: QxJ9d_1  reason: collision with other method in class */
        public boolean m303QxJ9d_1() {
            return this.f423QxJ9d_1;
        }

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public Bundle m299KQgRr5e_0() {
            return this.f419KQgRr5e_0;
        }

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public boolean m301KQgRr5e_0() {
            return this.f421KQgRr5e_0;
        }

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public Xgtqvk_8[] m302KQgRr5e_0() {
            return this.f424QxJ9d_1;
        }
    }

    /* compiled from: NotificationCompat.java */
    /* loaded from: classes.dex */
    public static abstract class PGPF6hQ_2 {
        public abstract RemoteViews KQgRr5e_0(X6FRs_4 x6FRs_4);

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public abstract void m305KQgRr5e_0(X6FRs_4 x6FRs_4);

        public abstract void KQgRr5e_0(Bundle bundle);

        public abstract RemoteViews PGPF6hQ_2(X6FRs_4 x6FRs_4);

        public abstract RemoteViews QxJ9d_1(X6FRs_4 x6FRs_4);
    }

    /* compiled from: NotificationCompat.java */
    /* loaded from: classes.dex */
    public static class QxJ9d_1 {

        /* renamed from: IFxWkV_5  reason: collision with other field name */
        public boolean f425IFxWkV_5;

        /* renamed from: IMuAHx_6  reason: collision with other field name */
        public boolean f426IMuAHx_6;
        public int KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public long f427KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public PGPF6hQ_2 f428KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public Notification f429KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public PendingIntent f430KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public Context f431KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public Bitmap f432KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public Bundle f433KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public RemoteViews f434KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public CharSequence f435KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public String f436KQgRr5e_0;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public CharSequence[] f439KQgRr5e_0;

        /* renamed from: Mqv2r_3  reason: collision with root package name */
        public int f3116Mqv2r_3;

        /* renamed from: Mqv2r_3  reason: collision with other field name */
        public RemoteViews f440Mqv2r_3;

        /* renamed from: Mqv2r_3  reason: collision with other field name */
        public CharSequence f441Mqv2r_3;

        /* renamed from: Mqv2r_3  reason: collision with other field name */
        public String f442Mqv2r_3;

        /* renamed from: Mqv2r_3  reason: collision with other field name */
        public boolean f443Mqv2r_3;
        public int PGPF6hQ_2;

        /* renamed from: PGPF6hQ_2  reason: collision with other field name */
        public RemoteViews f444PGPF6hQ_2;

        /* renamed from: PGPF6hQ_2  reason: collision with other field name */
        public CharSequence f445PGPF6hQ_2;

        /* renamed from: PGPF6hQ_2  reason: collision with other field name */
        public String f446PGPF6hQ_2;
        @Deprecated

        /* renamed from: PGPF6hQ_2  reason: collision with other field name */
        public ArrayList<String> f447PGPF6hQ_2;

        /* renamed from: PGPF6hQ_2  reason: collision with other field name */
        public boolean f448PGPF6hQ_2;
        public int QxJ9d_1;

        /* renamed from: QxJ9d_1  reason: collision with other field name */
        public Notification f449QxJ9d_1;

        /* renamed from: QxJ9d_1  reason: collision with other field name */
        public PendingIntent f450QxJ9d_1;

        /* renamed from: QxJ9d_1  reason: collision with other field name */
        public RemoteViews f451QxJ9d_1;

        /* renamed from: QxJ9d_1  reason: collision with other field name */
        public CharSequence f452QxJ9d_1;

        /* renamed from: QxJ9d_1  reason: collision with other field name */
        public String f453QxJ9d_1;

        /* renamed from: QxJ9d_1  reason: collision with other field name */
        public boolean f455QxJ9d_1;

        /* renamed from: X6FRs_4  reason: collision with other field name */
        public String f456X6FRs_4;

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public ArrayList<KQgRr5e_0> f437KQgRr5e_0 = new ArrayList<>();

        /* renamed from: QxJ9d_1  reason: collision with other field name */
        public ArrayList<KQgRr5e_0> f454QxJ9d_1 = new ArrayList<>();

        /* renamed from: KQgRr5e_0  reason: collision with other field name */
        public boolean f438KQgRr5e_0 = true;

        /* renamed from: X6FRs_4  reason: collision with other field name */
        public boolean f457X6FRs_4 = false;

        /* renamed from: X6FRs_4  reason: collision with root package name */
        public int f3117X6FRs_4 = 0;

        /* renamed from: IFxWkV_5  reason: collision with root package name */
        public int f3114IFxWkV_5 = 0;

        /* renamed from: IMuAHx_6  reason: collision with root package name */
        public int f3115IMuAHx_6 = 0;

        /* renamed from: FSaI4_7  reason: collision with root package name */
        public int f3113FSaI4_7 = 0;

        public QxJ9d_1(Context context, String str) {
            Notification notification = new Notification();
            this.f449QxJ9d_1 = notification;
            this.f431KQgRr5e_0 = context;
            this.f442Mqv2r_3 = str;
            notification.when = System.currentTimeMillis();
            this.f449QxJ9d_1.audioStreamType = -1;
            this.QxJ9d_1 = 0;
            this.f447PGPF6hQ_2 = new ArrayList<>();
        }

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public QxJ9d_1 m306KQgRr5e_0(CharSequence charSequence) {
            this.f452QxJ9d_1 = KQgRr5e_0(charSequence);
            return this;
        }

        public QxJ9d_1 PGPF6hQ_2(int i) {
            this.f449QxJ9d_1.icon = i;
            return this;
        }

        public QxJ9d_1 QxJ9d_1(CharSequence charSequence) {
            this.f435KQgRr5e_0 = KQgRr5e_0(charSequence);
            return this;
        }

        public QxJ9d_1 KQgRr5e_0(int i, int i2, boolean z) {
            this.PGPF6hQ_2 = i;
            this.f3116Mqv2r_3 = i2;
            this.f448PGPF6hQ_2 = z;
            return this;
        }

        public QxJ9d_1 PGPF6hQ_2(CharSequence charSequence) {
            this.f449QxJ9d_1.tickerText = KQgRr5e_0(charSequence);
            return this;
        }

        public QxJ9d_1 QxJ9d_1(boolean z) {
            KQgRr5e_0(2, z);
            return this;
        }

        public QxJ9d_1 PGPF6hQ_2(boolean z) {
            KQgRr5e_0(8, z);
            return this;
        }

        public QxJ9d_1 QxJ9d_1(int i) {
            this.QxJ9d_1 = i;
            return this;
        }

        public QxJ9d_1 KQgRr5e_0(boolean z) {
            KQgRr5e_0(16, z);
            return this;
        }

        public QxJ9d_1 KQgRr5e_0(int i) {
            Notification notification = this.f449QxJ9d_1;
            notification.defaults = i;
            if ((i & 4) != 0) {
                notification.flags |= 1;
            }
            return this;
        }

        public final void KQgRr5e_0(int i, boolean z) {
            if (z) {
                Notification notification = this.f449QxJ9d_1;
                notification.flags = i | notification.flags;
                return;
            }
            Notification notification2 = this.f449QxJ9d_1;
            notification2.flags = (i ^ (-1)) & notification2.flags;
        }

        /* renamed from: KQgRr5e_0  reason: collision with other method in class */
        public Bundle m307KQgRr5e_0() {
            if (this.f433KQgRr5e_0 == null) {
                this.f433KQgRr5e_0 = new Bundle();
            }
            return this.f433KQgRr5e_0;
        }

        public QxJ9d_1 KQgRr5e_0(KQgRr5e_0 kQgRr5e_0) {
            this.f437KQgRr5e_0.add(kQgRr5e_0);
            return this;
        }

        public Notification KQgRr5e_0() {
            return new IMuAHx_6(this).KQgRr5e_0();
        }

        public static CharSequence KQgRr5e_0(CharSequence charSequence) {
            return (charSequence != null && charSequence.length() > 5120) ? charSequence.subSequence(0, 5120) : charSequence;
        }
    }

    public static Bundle KQgRr5e_0(Notification notification) {
        int i = Build.VERSION.SDK_INT;
        if (i >= 19) {
            return notification.extras;
        }
        if (i >= 16) {
            return FSaI4_7.KQgRr5e_0(notification);
        }
        return null;
    }
}
